/*******************************************************************************
* File Name: Audio_IDAC8.c
* Version 2.0
*
* Description:
*  This file provides the power management source code to API for the
*  IDAC8.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include "Audio_IDAC8.h"

static Audio_IDAC8_backupStruct Audio_IDAC8_backup;


/*******************************************************************************
* Function Name: Audio_IDAC8_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Audio_IDAC8_SaveConfig(void) 
{
    if (!((Audio_IDAC8_CR1 & Audio_IDAC8_SRC_MASK) == Audio_IDAC8_SRC_UDB))
    {
        Audio_IDAC8_backup.data_value = Audio_IDAC8_Data;
    }
}


/*******************************************************************************
* Function Name: Audio_IDAC8_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Audio_IDAC8_RestoreConfig(void) 
{
    if (!((Audio_IDAC8_CR1 & Audio_IDAC8_SRC_MASK) == Audio_IDAC8_SRC_UDB))
    {
        if((Audio_IDAC8_Strobe & Audio_IDAC8_STRB_MASK) == Audio_IDAC8_STRB_EN)
        {
            Audio_IDAC8_Strobe &= (uint8)(~Audio_IDAC8_STRB_MASK);
            Audio_IDAC8_Data = Audio_IDAC8_backup.data_value;
            Audio_IDAC8_Strobe |= Audio_IDAC8_STRB_EN;
        }
        else
        {
            Audio_IDAC8_Data = Audio_IDAC8_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: Audio_IDAC8_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
* Global variables:
*  Audio_IDAC8_backup.enableState: Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void Audio_IDAC8_Sleep(void) 
{
    if(Audio_IDAC8_ACT_PWR_EN == (Audio_IDAC8_PWRMGR & Audio_IDAC8_ACT_PWR_EN))
    {
        /* IDAC8 is enabled */
        Audio_IDAC8_backup.enableState = 1u;
    }
    else
    {
        /* IDAC8 is disabled */
        Audio_IDAC8_backup.enableState = 0u;
    }

    Audio_IDAC8_Stop();
    Audio_IDAC8_SaveConfig();
}


/*******************************************************************************
* Function Name: Audio_IDAC8_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Audio_IDAC8_backup.enableState: Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Audio_IDAC8_Wakeup(void) 
{
    Audio_IDAC8_RestoreConfig();
    
    if(Audio_IDAC8_backup.enableState == 1u)
    {
        /* Enable IDAC8's operation */
        Audio_IDAC8_Enable();
        
        /* Set the data register */
        Audio_IDAC8_SetValue(Audio_IDAC8_Data);
    } /* Do nothing if IDAC8 was disabled before */    
}


/* [] END OF FILE */
