/*******************************************************************************
* File Name: DSP_DFB.h
* Version 1.40
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the DFB Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2011-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_DFB_DSP_DFB_H) /* DFB Header File */
#define CY_DFB_DSP_DFB_H

#include "CyLib.h"

extern uint8 DSP_DFB_initVar;


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define DSP_DFB_OPTIMIZE_ASSEMBLY      (1u)
#define DSP_DFB_INIT_INTERRUPT_MODE    (4u)
#define DSP_DFB_INIT_DMA_MODE          (5u)
#define DSP_DFB_INIT_OUT1_SOURCE       (2u)
#define DSP_DFB_INIT_OUT2_SOURCE       (0u)

/* Sizes of current DFB program */
#define DSP_DFB_DA_RAM_SIZE_CUR        (0x7Eu)
#define DSP_DFB_DB_RAM_SIZE_CUR        (0x7Du)
#define DSP_DFB_CSA_RAM_SIZE_CUR       (0x18u)
#define DSP_DFB_CSB_RAM_SIZE_CUR       (0x12u)
#define DSP_DFB_CFSM_RAM_SIZE_CUR      (0x20u)
#define DSP_DFB_ACU_RAM_SIZE_CUR       (0x0Cu)


/***************************************
*     Data Types Definitions
***************************************/

#if (DSP_DFB_OPTIMIZE_ASSEMBLY)
    extern const uint32 CYCODE DSP_DFB_cstoreA[DSP_DFB_CSA_RAM_SIZE_CUR];
    extern const uint32 CYCODE DSP_DFB_cstoreB[DSP_DFB_CSB_RAM_SIZE_CUR];
#else
    extern const uint32 CYCODE DSP_DFB_control[DSP_DFB_CSA_RAM_SIZE_CUR];
#endif /* DSP_DFB_OPTIMIZE_ASSEMBLY */

extern const uint32 CYCODE DSP_DFB_data_a[DSP_DFB_DA_RAM_SIZE_CUR];
extern const uint32 CYCODE DSP_DFB_data_b[DSP_DFB_DB_RAM_SIZE_CUR];
extern const uint32 CYCODE DSP_DFB_cfsm[DSP_DFB_CFSM_RAM_SIZE_CUR];
extern const uint32 CYCODE DSP_DFB_acu[DSP_DFB_ACU_RAM_SIZE_CUR];

/* Sleep Mode API Support */
typedef struct
{
    uint8  enableState;
    uint8  cr;
    uint8  sr;
    uint8  sem;
    uint32 acu[DSP_DFB_ACU_RAM_SIZE_CUR];
} DSP_DFB_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void   DSP_DFB_Init(void) ;
void   DSP_DFB_Enable(void) ;
void   DSP_DFB_Start(void) ;
void   DSP_DFB_Stop(void) ;
void   DSP_DFB_Pause(void) ;
void   DSP_DFB_Resume(void) ;
void   DSP_DFB_SetCoherency(uint8 coherencyKeyByte) ;
void   DSP_DFB_SetDalign(uint8 dalignKeyByte) ;
uint8  DSP_DFB_LoadDataRAMA(const int32 ptr[], uint32 addr[], uint8 size)
        ;
uint8  DSP_DFB_LoadDataRAMB(const int32 ptr[], uint32 addr[], uint8 size)
        ;
void   DSP_DFB_LoadInputValue(uint8 channel, int32 sample)
        ;
int32  DSP_DFB_GetOutputValue(uint8 channel) ;
void   DSP_DFB_SetInterruptMode(uint8 events) ;
uint8  DSP_DFB_GetInterruptSource(void) ;
void   DSP_DFB_ClearInterrupt(uint8 interruptMask) ;
void   DSP_DFB_SetDMAMode(uint8 events) ;
void   DSP_DFB_SetSemaphores(uint8 mask) ;
uint8  DSP_DFB_GetSemaphores(void) ;
void   DSP_DFB_ClearSemaphores(uint8 mask) ;
void   DSP_DFB_SetOutput1Source(uint8 source) ;
void   DSP_DFB_SetOutput2Source(uint8 source) ;
void   DSP_DFB_Sleep(void) ;
void   DSP_DFB_Wakeup(void) ;
void   DSP_DFB_SaveConfig(void) ;
void   DSP_DFB_RestoreConfig(void) ;

/* Macros */
#define DSP_DFB_ClearInterruptSource(event) \
do { \
    DSP_DFB_SR_REG = (uint8) (((event) & DSP_DFB_EVENT_MASK) << DSP_DFB_SR_EVENT_SHIFT); \
} while (0)


/***************************************
*           API Constants
***************************************/

/* Channel Definitions */
#define DSP_DFB_CHANNEL_A              (1u)
#define DSP_DFB_CHANNEL_B              (0u)

/* Sizes of DFB memories */
#define DSP_DFB_DA_RAM_SIZE            (0x80u)
#define DSP_DFB_DB_RAM_SIZE            (0x80u)
#define DSP_DFB_CSA_RAM_SIZE           (0x40u)
#define DSP_DFB_CSB_RAM_SIZE           (0x40u)
#define DSP_DFB_CFSM_RAM_SIZE          (0x40u)
#define DSP_DFB_ACU_RAM_SIZE           (0x10u)

#define DSP_DFB_SUCCESS                (CYRET_SUCCESS)
#define DSP_DFB_DATA_OUT_OF_RANGE      (0xFEu)
#define DSP_DFB_ADDRESS_OUT_OF_RANGE   (0xFFu)


/***************************************
*             Registers
***************************************/

/* RAM memory map offsets */
#define DSP_DFB_DA_RAM_REG             (* (reg32 *) (DSP_DFB_DFB__DPA_SRAM_DATA))
#define DSP_DFB_DA_RAM_PTR             (  (reg32 *) (DSP_DFB_DFB__DPA_SRAM_DATA))
#define DSP_DFB_DB_RAM_REG             (* (reg32 *) (DSP_DFB_DFB__DPB_SRAM_DATA))
#define DSP_DFB_DB_RAM_PTR             (  (reg32 *) (DSP_DFB_DFB__DPB_SRAM_DATA))
#define DSP_DFB_CSA_RAM_REG            (* (reg32 *) (DSP_DFB_DFB__CSA_SRAM_DATA))
#define DSP_DFB_CSA_RAM_PTR            (  (reg32 *) (DSP_DFB_DFB__CSA_SRAM_DATA))
#define DSP_DFB_CSB_RAM_REG            (* (reg32 *) (DSP_DFB_DFB__CSB_SRAM_DATA))
#define DSP_DFB_CSB_RAM_PTR            (  (reg32 *) (DSP_DFB_DFB__CSB_SRAM_DATA))
#define DSP_DFB_CFSM_RAM_REG           (* (reg32 *) (DSP_DFB_DFB__FSM_SRAM_DATA))
#define DSP_DFB_CFSM_RAM_PTR           (  (reg32 *) (DSP_DFB_DFB__FSM_SRAM_DATA))
#define DSP_DFB_ACU_RAM_REG            (* (reg32 *) (DSP_DFB_DFB__ACU_SRAM_DATA))
#define DSP_DFB_ACU_RAM_PTR            (  (reg32 *) (DSP_DFB_DFB__ACU_SRAM_DATA))

#define DSP_DFB_SEM_REG                (* (reg8 *) DSP_DFB_DFB__SEMA)
#define DSP_DFB_SEM_PTR                (  (reg8 *) DSP_DFB_DFB__SEMA)
#define DSP_DFB_CR_REG                 (* (reg8 *) DSP_DFB_DFB__CR)
#define DSP_DFB_CR_PTR                 (  (reg8 *) DSP_DFB_DFB__CR)
#define DSP_DFB_SR_REG                 (* (reg8 *) DSP_DFB_DFB__SR)
#define DSP_DFB_SR_PTR                 (  (reg8 *) DSP_DFB_DFB__SR)
#define DSP_DFB_INT_CTRL_REG           (* (reg8 *) DSP_DFB_DFB__INT_CTRL)
#define DSP_DFB_INT_CTRL_PTR           (  (reg8 *) DSP_DFB_DFB__INT_CTRL)
#define DSP_DFB_DMA_CTRL_REG           (* (reg8 *) DSP_DFB_DFB__DMA_CTRL)
#define DSP_DFB_DMA_CTRL_PTR           (  (reg8 *) DSP_DFB_DFB__DMA_CTRL)
#define DSP_DFB_RAM_DIR_REG            (* (reg8 *) DSP_DFB_DFB__RAM_DIR)
#define DSP_DFB_RAM_DIR_PTR            (  (reg8 *) DSP_DFB_DFB__RAM_DIR)

#define DSP_DFB_DALIGN_REG             (* (reg8 *) DSP_DFB_DFB__DALIGN)
#define DSP_DFB_DALIGN_PTR             (  (reg8 *) DSP_DFB_DFB__DALIGN)
#define DSP_DFB_DSI_CTRL_REG           (* (reg8 *) DSP_DFB_DFB__DSI_CTRL)
#define DSP_DFB_DSI_CTRL_PTR           (  (reg8 *) DSP_DFB_DFB__DSI_CTRL)
#define DSP_DFB_HOLDA_REG              (* (reg8 *) DSP_DFB_DFB__HOLDA)
#define DSP_DFB_HOLDA_PTR              (  (reg8 *) DSP_DFB_DFB__HOLDA)
#define DSP_DFB_HOLDAH_REG             (* (reg8 *) DSP_DFB_DFB__HOLDAH)
#define DSP_DFB_HOLDAH_PTR             (  (reg8 *) DSP_DFB_DFB__HOLDAH)
#define DSP_DFB_HOLDAM_REG             (* (reg8 *) DSP_DFB_DFB__HOLDAM)
#define DSP_DFB_HOLDAM_PTR             (  (reg8 *) DSP_DFB_DFB__HOLDAM)
#define DSP_DFB_HOLDB_REG              (* (reg8 *) DSP_DFB_DFB__HOLDB)
#define DSP_DFB_HOLDB_PTR              (  (reg8 *) DSP_DFB_DFB__HOLDB)
#define DSP_DFB_HOLDBH_REG             (* (reg8 *) DSP_DFB_DFB__HOLDBH)
#define DSP_DFB_HOLDBH_PTR             (  (reg8 *) DSP_DFB_DFB__HOLDBH)
#define DSP_DFB_HOLDBM_REG             (* (reg8 *) DSP_DFB_DFB__HOLDBM)
#define DSP_DFB_HOLDBM_PTR             (  (reg8 *) DSP_DFB_DFB__HOLDBM)
#define DSP_DFB_PM_ACT_CFG_REG         (* (reg8 *) DSP_DFB_DFB__PM_ACT_CFG)
#define DSP_DFB_PM_ACT_CFG_PTR         (  (reg8 *) DSP_DFB_DFB__PM_ACT_CFG)
#define DSP_DFB_PM_STBY_CFG_REG        (* (reg8 *) DSP_DFB_DFB__PM_STBY_CFG)
#define DSP_DFB_PM_STBY_CFG_PTR        (  (reg8 *) DSP_DFB_DFB__PM_STBY_CFG)
#define DSP_DFB_RAM_EN_REG             (* (reg8 *) DSP_DFB_DFB__RAM_EN)
#define DSP_DFB_RAM_EN_PTR             (  (reg8 *) DSP_DFB_DFB__RAM_EN)
#define DSP_DFB_STAGEA_REG             (* (reg8 *) DSP_DFB_DFB__STAGEA)
#define DSP_DFB_STAGEA_PTR             (  (reg8 *) DSP_DFB_DFB__STAGEA)
#define DSP_DFB_STAGEAH_REG            (* (reg8 *) DSP_DFB_DFB__STAGEAH)
#define DSP_DFB_STAGEAH_PTR            (  (reg8 *) DSP_DFB_DFB__STAGEAH)
#define DSP_DFB_STAGEAM_REG            (* (reg8 *) DSP_DFB_DFB__STAGEAM)
#define DSP_DFB_STAGEAM_PTR            (  (reg8 *) DSP_DFB_DFB__STAGEAM)
#define DSP_DFB_STAGEB_REG             (* (reg8 *) DSP_DFB_DFB__STAGEB)
#define DSP_DFB_STAGEB_PTR             (  (reg8 *) DSP_DFB_DFB__STAGEB)
#define DSP_DFB_STAGEBH_REG            (* (reg8 *) DSP_DFB_DFB__STAGEBH)
#define DSP_DFB_STAGEBH_PTR            (  (reg8 *) DSP_DFB_DFB__STAGEBH)
#define DSP_DFB_STAGEBM_REG            (* (reg8 *) DSP_DFB_DFB__STAGEBM)
#define DSP_DFB_STAGEBM_PTR            (  (reg8 *) DSP_DFB_DFB__STAGEBM)
#define DSP_DFB_COHER_REG              (* (reg8 *) DSP_DFB_DFB__COHER)
#define DSP_DFB_COHER_PTR              (  (reg8 *) DSP_DFB_DFB__COHER)

#define DSP_DFB_DA_RAM_LAST_ELEM_PTR   (  (reg32 *) (DSP_DFB_DFB__DPB_SRAM_DATA - 4u))
#define DSP_DFB_DB_RAM_LAST_ELEM_PTR   (  (reg32 *) (DSP_DFB_DFB__CSA_SRAM_DATA - 4u))


/***************************************
*       Register Constants
***************************************/

#define DSP_DFB_PM_ACT_MSK             (DSP_DFB_DFB__PM_ACT_MSK)
#define DSP_DFB_PM_STBY_MSK            (DSP_DFB_DFB__PM_STBY_MSK)

#define DSP_DFB_RUN_MASK               (0x01u)
#define DSP_DFB_CORECLK_DISABLE        (0x04u)
#define DSP_DFB_RAM_DIR_BUS            (0x3Fu)
#define DSP_DFB_RAM_DIR_DFB            (0x00u)
#define DSP_DFB_RAM_DPA_DIR            (0x10u)
#define DSP_DFB_RAM_DPB_DIR            (0x20u)

/* Mask for bits within DFB Coherency Register */
#define DSP_DFB_STGA_KEY_SHIFT         (0x00u)
#define DSP_DFB_STGB_KEY_SHIFT         (0x02u)
#define DSP_DFB_HOLDA_KEY_SHIFT        (0x04u)
#define DSP_DFB_HOLDB_KEY_SHIFT        (0x06u)

#define DSP_DFB_STGA_KEY_LOW           ((uint8) (0x00u << DSP_DFB_STGA_KEY_SHIFT))
#define DSP_DFB_STGA_KEY_MID           ((uint8) (0x01u << DSP_DFB_STGA_KEY_SHIFT))
#define DSP_DFB_STGA_KEY_HIGH          ((uint8) (0x02u << DSP_DFB_STGA_KEY_SHIFT))
#define DSP_DFB_STGB_KEY_LOW           ((uint8) (0x00u << DSP_DFB_STGB_KEY_SHIFT))
#define DSP_DFB_STGB_KEY_MID           ((uint8) (0x01u << DSP_DFB_STGB_KEY_SHIFT))
#define DSP_DFB_STGB_KEY_HIGH          ((uint8) (0x02u << DSP_DFB_STGB_KEY_SHIFT))
#define DSP_DFB_HOLDA_KEY_LOW          ((uint8) (0x00u << DSP_DFB_HOLDA_KEY_SHIFT))
#define DSP_DFB_HOLDA_KEY_MID          ((uint8) (0x01u << DSP_DFB_HOLDA_KEY_SHIFT))
#define DSP_DFB_HOLDA_KEY_HIGH         ((uint8) (0x02u << DSP_DFB_HOLDA_KEY_SHIFT))
#define DSP_DFB_HOLDB_KEY_LOW          ((uint8) (0x00u << DSP_DFB_HOLDB_KEY_SHIFT))
#define DSP_DFB_HOLDB_KEY_MID          ((uint8) (0x01u << DSP_DFB_HOLDB_KEY_SHIFT))
#define DSP_DFB_HOLDB_KEY_HIGH         ((uint8) (0x02u << DSP_DFB_HOLDB_KEY_SHIFT))

/* Mask for bits within DFB Data Alignment Register */
#define DSP_DFB_STGA_DALIGN_SHIFT      (0x00u)
#define DSP_DFB_STGB_DALIGN_SHIFT      (0x01u)
#define DSP_DFB_HOLDA_DALIGN_SHIFT     (0x02u)
#define DSP_DFB_HOLDB_DALIGN_SHIFT     (0x03u)

#define DSP_DFB_STGA_DALIGN_LOW        ((uint8) (0x00u << DSP_DFB_STGA_DALIGN_SHIFT))
#define DSP_DFB_STGA_DALIGN_HIGH       ((uint8) (0x01u << DSP_DFB_STGA_DALIGN_SHIFT))
#define DSP_DFB_STGB_DALIGN_LOW        ((uint8) (0x00u << DSP_DFB_STGB_DALIGN_SHIFT))
#define DSP_DFB_STGB_DALIGN_HIGH       ((uint8) (0x01u << DSP_DFB_STGB_DALIGN_SHIFT))
#define DSP_DFB_HOLDA_DALIGN_LOW       ((uint8) (0x00u << DSP_DFB_HOLDA_DALIGN_SHIFT))
#define DSP_DFB_HOLDA_DALIGN_HIGH      ((uint8) (0x01u << DSP_DFB_HOLDA_DALIGN_SHIFT))
#define DSP_DFB_HOLDB_DALIGN_LOW       ((uint8) (0x00u << DSP_DFB_HOLDB_DALIGN_SHIFT))
#define DSP_DFB_HOLDB_DALIGN_HIGH      ((uint8) (0x01u << DSP_DFB_HOLDB_DALIGN_SHIFT))

/* Mask for bits within DFB Interrupt Control and Status Registers */
#define DSP_DFB_SEM_MASK               (0x07u)
#define DSP_DFB_SEM_ENABLE_SHIFT       (0x04u)
#define DSP_DFB_EVENT_MASK             (0x1Fu)
#define DSP_DFB_SR_EVENT_SHIFT         (0x03u)

#define DSP_DFB_HOLDA_SHIFT            (0x00u)
#define DSP_DFB_HOLDB_SHIFT            (0x01u)
#define DSP_DFB_SEMA0_SHIFT            (0x02u)
#define DSP_DFB_SEMA1_SHIFT            (0x03u)
#define DSP_DFB_SEMA2_SHIFT            (0x04u)

#define DSP_DFB_HOLDA                  ((uint8) (0x01u << DSP_DFB_HOLDA_SHIFT))
#define DSP_DFB_HOLDB                  ((uint8) (0x01u << DSP_DFB_HOLDB_SHIFT))
#define DSP_DFB_SEMA0                  ((uint8) (0x01u << DSP_DFB_SEMA0_SHIFT))
#define DSP_DFB_SEMA1                  ((uint8) (0x01u << DSP_DFB_SEMA1_SHIFT))
#define DSP_DFB_SEMA2                  ((uint8) (0x01u << DSP_DFB_SEMA2_SHIFT))

/* Mask for bits within DFB DMAREQ Control Register */
#define DSP_DFB_DMA_CTRL_MASK          (0x0Fu)
#define DSP_DFB_DMAREQ1_DISABLED       (0x00u)
#define DSP_DFB_DMAREQ1_HOLDA          (0x01u)
#define DSP_DFB_DMAREQ1_SEM0           (0x02u)
#define DSP_DFB_DMAREQ1_SEM1           (0x03u)
#define DSP_DFB_DMAREQ2_DISABLED       (0x00u)
#define DSP_DFB_DMAREQ2_HOLDB          (0x04u)
#define DSP_DFB_DMAREQ2_SEM0           (0x08u)
#define DSP_DFB_DMAREQ2_SEM1           (0x0Cu)

/* Mask for bits within DFB Semaphore Register */
#define DSP_DFB_SEMAPHORE0             (0x01u)
#define DSP_DFB_SEMAPHORE1             (0x02u)
#define DSP_DFB_SEMAPHORE2             (0x04u)

/* Mask for bits within Global Control Register */
#define DSP_DFB_DFB_RUN                (0x00u)
#define DSP_DFB_SEM0                   (0x01u)
#define DSP_DFB_SEM1                   (0x02u)
#define DSP_DFB_DFB_INTR               (0x03u)
#define DSP_DFB_SEM2                   (0x00u)
#define DSP_DFB_DPSIGN                 (0x04u)
#define DSP_DFB_DPTHRESH               (0x08u)
#define DSP_DFB_DPEQ                   (0x0Cu)
#define DSP_DFB_DFB_GBL1_OUT_MASK      (0xFCu)
#define DSP_DFB_DFB_GBL2_OUT_MASK      (0xF3u)

#endif /* End DFB Header File */


/* [] END OF FILE */

