/***************************************************************************
* File Name: DSP_DMA_IN1_Simulator_dma.c  
* Version 1.70
*
*  Description:
*   Provides an API for the DMAC component. The API includes functions
*   for the DMA controller, DMA channels and Transfer Descriptors.
*
*
*   Note:
*     This module requires the developer to finish or fill in the auto
*     generated funcions and setup the dma channel and TD's.
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
#include <CYLIB.H>
#include <CYDMAC.H>
#include <DSP_DMA_IN1_Simulator_dma.H>



/****************************************************************************
* 
* The following defines are available in Cyfitter.h
* 
* 
* 
* DSP_DMA_IN1_Simulator__DRQ_CTL_REG
* 
* 
* DSP_DMA_IN1_Simulator__DRQ_NUMBER
* 
* Number of TD's used by this channel.
* DSP_DMA_IN1_Simulator__NUMBEROF_TDS
* 
* Priority of this channel.
* DSP_DMA_IN1_Simulator__PRIORITY
* 
* True if DSP_DMA_IN1_Simulator_TERMIN_SEL is used.
* DSP_DMA_IN1_Simulator__TERMIN_EN
* 
* TERMIN interrupt line to signal terminate.
* DSP_DMA_IN1_Simulator__TERMIN_SEL
* 
* 
* True if DSP_DMA_IN1_Simulator_TERMOUT0_SEL is used.
* DSP_DMA_IN1_Simulator__TERMOUT0_EN
* 
* 
* TERMOUT0 interrupt line to signal completion.
* DSP_DMA_IN1_Simulator__TERMOUT0_SEL
* 
* 
* True if DSP_DMA_IN1_Simulator_TERMOUT1_SEL is used.
* DSP_DMA_IN1_Simulator__TERMOUT1_EN
* 
* 
* TERMOUT1 interrupt line to signal completion.
* DSP_DMA_IN1_Simulator__TERMOUT1_SEL
* 
****************************************************************************/


/* Zero based index of DSP_DMA_IN1_Simulator dma channel */
uint8 DSP_DMA_IN1_Simulator_DmaHandle = DMA_INVALID_CHANNEL;

/*********************************************************************
* Function Name: uint8 DSP_DMA_IN1_Simulator_DmaInitalize
**********************************************************************
* Summary:
*   Allocates and initialises a channel of the DMAC to be used by the
*   caller.
*
* Parameters:
*   BurstCount.
*       
*       
*   ReqestPerBurst.
*       
*       
*   UpperSrcAddress.
*       
*       
*   UpperDestAddress.
*       
*
* Return:
*   The channel that can be used by the caller for DMA activity.
*   DMA_INVALID_CHANNEL (0xFF) if there are no channels left. 
*
*
*******************************************************************/
uint8 DSP_DMA_IN1_Simulator_DmaInitialize(uint8 BurstCount, uint8 ReqestPerBurst, uint16 UpperSrcAddress, uint16 UpperDestAddress) 
{

    /* Allocate a DMA channel. */
    DSP_DMA_IN1_Simulator_DmaHandle = (uint8)DSP_DMA_IN1_Simulator__DRQ_NUMBER;

    /* Configure the channel. */
    (void)CyDmaChSetConfiguration(DSP_DMA_IN1_Simulator_DmaHandle,
                                  BurstCount,
                                  ReqestPerBurst,
                                  (uint8)DSP_DMA_IN1_Simulator__TERMOUT0_SEL,
                                  (uint8)DSP_DMA_IN1_Simulator__TERMOUT1_SEL,
                                  (uint8)DSP_DMA_IN1_Simulator__TERMIN_SEL);

    /* Set the extended address for the transfers */
    (void)CyDmaChSetExtendedAddress(DSP_DMA_IN1_Simulator_DmaHandle, UpperSrcAddress, UpperDestAddress);

    /* Set the priority for this channel */
    (void)CyDmaChPriority(DSP_DMA_IN1_Simulator_DmaHandle, (uint8)DSP_DMA_IN1_Simulator__PRIORITY);
    
    return DSP_DMA_IN1_Simulator_DmaHandle;
}

/*********************************************************************
* Function Name: void DSP_DMA_IN1_Simulator_DmaRelease
**********************************************************************
* Summary:
*   Frees the channel associated with DSP_DMA_IN1_Simulator.
*
*
* Parameters:
*   void.
*
*
*
* Return:
*   void.
*
*******************************************************************/
void DSP_DMA_IN1_Simulator_DmaRelease(void) 
{
    /* Disable the channel */
    (void)CyDmaChDisable(DSP_DMA_IN1_Simulator_DmaHandle);
}

