/*******************************************************************************
* File Name: Monitoring_Opamp_VREF_PM.c
* Version 1.90
*
* Description:
*  This file provides the power management source code to the API for the 
*  OpAmp (Analog Buffer) component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Monitoring_Opamp_VREF.h"

static Monitoring_Opamp_VREF_BACKUP_STRUCT  Monitoring_Opamp_VREF_backup;


/*******************************************************************************  
* Function Name: Monitoring_Opamp_VREF_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration registers.
* 
* Parameters:
*  void
* 
* Return:
*  void
*
*******************************************************************************/
void Monitoring_Opamp_VREF_SaveConfig(void) 
{
    /* Nothing to save as registers are System reset on retention flops */
}


/*******************************************************************************  
* Function Name: Monitoring_Opamp_VREF_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration registers.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void Monitoring_Opamp_VREF_RestoreConfig(void) 
{
    /* Nothing to restore */
}


/*******************************************************************************   
* Function Name: Monitoring_Opamp_VREF_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Monitoring_Opamp_VREF_backup: The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
*******************************************************************************/
void Monitoring_Opamp_VREF_Sleep(void) 
{
    /* Save OpAmp enable state */
    if((Monitoring_Opamp_VREF_PM_ACT_CFG_REG & Monitoring_Opamp_VREF_ACT_PWR_EN) != 0u)
    {
        /* Component is enabled */
        Monitoring_Opamp_VREF_backup.enableState = 1u;
         /* Stops the component */
         Monitoring_Opamp_VREF_Stop();
    }
    else
    {
        /* Component is disabled */
        Monitoring_Opamp_VREF_backup.enableState = 0u;
    }
    /* Saves the configuration */
    Monitoring_Opamp_VREF_SaveConfig();
}


/*******************************************************************************  
* Function Name: Monitoring_Opamp_VREF_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  Monitoring_Opamp_VREF_backup: The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
*
*******************************************************************************/
void Monitoring_Opamp_VREF_Wakeup(void) 
{
    /* Restore the user configuration */
    Monitoring_Opamp_VREF_RestoreConfig();

    /* Enables the component operation */
    if(Monitoring_Opamp_VREF_backup.enableState == 1u)
    {
        Monitoring_Opamp_VREF_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
