/*******************************************************************************
* File Name: PowerBus_Comparator_IN.c
* Version 2.0
*
* Description:
*  This file provides the power management source code APIs for the
*  Comparator.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "PowerBus_Comparator_IN.h"

static PowerBus_Comparator_IN_backupStruct PowerBus_Comparator_IN_backup;


/*******************************************************************************
* Function Name: PowerBus_Comparator_IN_SaveConfig
********************************************************************************
*
* Summary:
*  Save the current user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
*******************************************************************************/
void PowerBus_Comparator_IN_SaveConfig(void) 
{
    /* Empty since all are system reset for retention flops */
}


/*******************************************************************************
* Function Name: PowerBus_Comparator_IN_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
********************************************************************************/
void PowerBus_Comparator_IN_RestoreConfig(void) 
{
    /* Empty since all are system reset for retention flops */    
}


/*******************************************************************************
* Function Name: PowerBus_Comparator_IN_Sleep
********************************************************************************
*
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
* Global variables:
*  PowerBus_Comparator_IN_backup.enableState:  Is modified depending on the enable 
*   state of the block before entering sleep mode.
*
*******************************************************************************/
void PowerBus_Comparator_IN_Sleep(void) 
{
    /* Save Comp's enable state */    
    if(PowerBus_Comparator_IN_ACT_PWR_EN == (PowerBus_Comparator_IN_PWRMGR & PowerBus_Comparator_IN_ACT_PWR_EN))
    {
        /* Comp is enabled */
        PowerBus_Comparator_IN_backup.enableState = 1u;
    }
    else
    {
        /* Comp is disabled */
        PowerBus_Comparator_IN_backup.enableState = 0u;
    }    
    
    PowerBus_Comparator_IN_Stop();
    PowerBus_Comparator_IN_SaveConfig();
}


/*******************************************************************************
* Function Name: PowerBus_Comparator_IN_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  PowerBus_Comparator_IN_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void PowerBus_Comparator_IN_Wakeup(void) 
{
    PowerBus_Comparator_IN_RestoreConfig();
    
    if(PowerBus_Comparator_IN_backup.enableState == 1u)
    {
        /* Enable Comp's operation */
        PowerBus_Comparator_IN_Enable();

    } /* Do nothing if Comp was disabled before */ 
}


/* [] END OF FILE */
