/*******************************************************************************
* File Name: Switches_SCModulator.c  
* Version 1.0
*
* Description:
*  This file provides the source code to the API for the ADC 
*  User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Switches_SCModulator.h"

uint8 Switches_SCModulator_initVar = 0u;

/*******************************************************************************   
* Function Name: Switches_SCModulator_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  Switches_SCModulator_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
* Reentrant:
*  No
* 
*******************************************************************************/
void Switches_SCModulator_Init(void)
{
    /* Set DelSig mode */
    Switches_SCModulator_CR0_REG = 
        (Switches_SCModulator_MODE_1ST_MOD << Switches_SCModulator_MODE_SHIFT);
	
    // set the input range
	Switches_SCModulator_CR1_REG = 
        (0 << Switches_SCModulator_GAIN_SHIFT) | 
        (Switches_SCModulator_DRIVE_400UA << Switches_SCModulator_DRIVE_SHIFT) | 
        (Switches_SCModulator_COMP_3P6PF << Switches_SCModulator_COMP_SHIFT);
    
    // set bias control and compensetaion
	Switches_SCModulator_CR2_REG = 
        (Switches_SCModulator_BIAS_CTL_2X << Switches_SCModulator_BIAS_CTL_SHIFT);
    
    // enable the clock source and enable dynamic control for modulator reset
	Switches_SCModulator_CLK_REG |= 
        (Switches_SCModulator_CLK_EN_ENABLE << Switches_SCModulator_CLK_EN_SHIFT) | 
        (Switches_SCModulator_DYN_CNTL_EN_ENABLE << Switches_SCModulator_DYN_CNTL_EN_SHIFT);
}

/*******************************************************************************   
* Function Name: Switches_SCModulator_Enable
********************************************************************************
*
* Summary:
*  Enables the ADC block operation
*
* Parameters:
*  void
*l
* Return:
*  void
*
* Reentrant:
*  No
* 
*******************************************************************************/
void Switches_SCModulator_Enable(void)
{
    // enable the internal pump clock for the SC/CT block
	Switches_SCModulator_PUMP_CR1_REG |= (Switches_SCModulator_PUMP_INTERNAL << Switches_SCModulator_PUMP_SHIFT);
	
	 /* Enable power to the Amp in Active mode*/
    Switches_SCModulator_PM_ACT_CFG_REG |= Switches_SCModulator_ACT_PWR_EN;
    
    /* Enable power to the Amp in Alt Active mode*/
    Switches_SCModulator_PM_STBY_CFG_REG |= Switches_SCModulator_STBY_PWR_EN;
	
	#if (CYDEV_VARIABLE_VDDA == 1u)
        if(CyScPumpEnabled == 1u)
        {
            Switches_SCModulator_BST_REG &= (uint8)(~Switches_SCModulator_MX_BST_CLK_MASK);
            Switches_SCModulator_BST_REG |= (uint8)(Switches_SCModulator_BST_CLK_EN_ENABLE << Switches_SCModulator_BST_CLK_EN_SHIFT) | CyScBoostClk__INDEX;
            Switches_SCModulator_SC_MISC_REG |= (uint8)(Switches_SCModulator_SC_PUMP_FORCE << Switches_SCModulator_SC_PUMP_FORCE_SHIFT);
            CyScBoostClk_Start();
        }
        else
        {
            Switches_SCModulator_BST_REG &= (uint8)(~Switches_SCModulator_MX_BST_CLK_MASK);
            Switches_SCModulator_SC_MISC_REG &= (uint8)(~Switches_SCModulator_SC_PUMP_FORCE_MASK);
        }
    #endif
}

/*******************************************************************************
* Function Name: Switches_SCModulator_Start
********************************************************************************
*
* Summary:
*  The start function initializes the PGA with the default values, and sets
*  the power to the given level.  A power level of 0, is the same as executing
*  the stop function.
*
* Parameters:  
*  void
*
* Return: 
*  void 
*
* Reentrant: 
*  No
*
*******************************************************************************/
void Switches_SCModulator_Start(void) 
{   

    if(Switches_SCModulator_initVar == 0u)
    {
        Switches_SCModulator_Init();
        Switches_SCModulator_initVar = 1u;
    }
    
    
    Switches_SCModulator_Enable();

	
}

/* [] END OF FILE */