/*******************************************************************************
* File Name: System_CAN_INT.c
* Version 3.0
*
* Description:
*  This file contains Interrupt Service Routine (ISR) for CAN Component.
*  The Interrupt handlers functions are generated accordingly to the PSoC
*  Creator Customizer inputs.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "System_CAN.h"
#include "cyapicallbacks.h"

/* `#START CAN_INT_C_CODE_DEFINITION` */

/* `#END` */

#if (System_CAN_ARB_LOST)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_ArbLostIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Arbitration Lost Interrupt. Clears
    *  Arbitration Lost interrupt flag. Only generated if Arbitration Lost
    *  Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_ArbLostIsr(void) 
    {
        /* Clear Arbitration Lost flag */
        System_CAN_INT_SR_REG.byte[0u] = System_CAN_ARBITRATION_LOST_MASK;

        /* `#START ARBITRATION_LOST_ISR` */

        /* `#END` */

        #ifdef System_CAN_ARB_LOST_ISR_CALLBACK
            System_CAN_ArbLostIsr_Callback();
        #endif /* System_CAN_ARB_LOST_ISR_CALLBACK */
    }
#endif /* System_CAN_ARB_LOST */


#if (System_CAN_OVERLOAD)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_OvrLdErrorIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Overload Error Interrupt. Clears Overload
    *  Error interrupt flag. Only generated if Overload Error Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_OvrLdErrorIsr(void) 
    {
        /* Clear Overload Error flag */
        System_CAN_INT_SR_REG.byte[0u] = System_CAN_OVERLOAD_ERROR_MASK;

        /* `#START OVER_LOAD_ERROR_ISR` */

        /* `#END` */

        #ifdef System_CAN_OVR_LD_ERROR_ISR_CALLBACK
            System_CAN_OvrLdErrorIsr_Callback();
        #endif /* System_CAN_OVR_LD_ERROR_ISR_CALLBACK */
    }
#endif /* System_CAN_OVERLOAD */


#if (System_CAN_BIT_ERR)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_BitErrorIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bit Error Interrupt. Clears Bit Error
    *  interrupt flag. Only generated if Bit Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_BitErrorIsr(void) 
    {
        /* Clear Bit Error flag */
        System_CAN_INT_SR_REG.byte[0u] = System_CAN_BIT_ERROR_MASK;

        /* `#START BIT_ERROR_ISR` */

        /* `#END` */

        #ifdef System_CAN_BIT_ERROR_ISR_CALLBACK
            System_CAN_BitErrorIsr_Callback();
        #endif /* System_CAN_BIT_ERROR_ISR_CALLBACK */
    }
#endif /* System_CAN_BIT_ERR */


#if (System_CAN_STUFF_ERR)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_BitStuffErrorIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bit Stuff Error Interrupt. Clears Bit Stuff
    *  Error interrupt flag. Only generated if Bit Stuff Error Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_BitStuffErrorIsr(void) 
    {
        /* Clear Stuff Error flag */
        System_CAN_INT_SR_REG.byte[0u] = System_CAN_STUFF_ERROR_MASK;

        /* `#START BIT_STUFF_ERROR_ISR` */

        /* `#END` */

        #ifdef System_CAN_BIT_STUFF_ERROR_ISR_CALLBACK
            System_CAN_BitStuffErrorIsr_Callback();
        #endif /* System_CAN_BIT_STUFF_ERROR_ISR_CALLBACK */
    }
#endif /* System_CAN_STUFF_ERR */


#if (System_CAN_ACK_ERR)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_AckErrorIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Acknowledge Error Interrupt. Clears
    *  Acknowledge Error interrupt flag. Only generated if Acknowledge Error
    *  Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_AckErrorIsr(void) 
    {
        /* Clear Acknoledge Error flag */
        System_CAN_INT_SR_REG.byte[0u] = System_CAN_ACK_ERROR_MASK;

        /* `#START ACKNOWLEDGE_ERROR_ISR` */

        /* `#END` */

        #ifdef System_CAN_ACK_ERROR_ISR_CALLBACK
            System_CAN_AckErrorIsr_Callback();
        #endif /* System_CAN_ACK_ERROR_ISR_CALLBACK */
    }
#endif /* System_CAN_ACK_ERR */


#if (System_CAN_FORM_ERR)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_MsgErrorIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Form Error Interrupt. Clears Form Error
    *  interrupt flag. Only generated if Form Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_MsgErrorIsr(void) 
    {
        /* Clear Form Error flag */
        System_CAN_INT_SR_REG.byte[0u] = System_CAN_FORM_ERROR_MASK;

        /* `#START MESSAGE_ERROR_ISR` */

        /* `#END` */

        #ifdef System_CAN_MSG_ERROR_ISR_CALLBACK
            System_CAN_MsgErrorIsr_Callback();
        #endif /* System_CAN_MSG_ERROR_ISR_CALLBACK */
    }
#endif /* System_CAN_FORM_ERR */


#if (System_CAN_CRC_ERR)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_CrcErrorIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to CRC Error Interrupt. Clears CRC Error
    *  interrupt flag. Only generated if CRC Error Interrupt enable in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_CrcErrorIsr(void) 
    {
        /* Clear CRC Error flag */
        System_CAN_INT_SR_REG.byte[1u] = System_CAN_CRC_ERROR_MASK;

        /* `#START CRC_ERROR_ISR` */

        /* `#END` */

        #ifdef System_CAN_CRC_ERROR_ISR_CALLBACK
            System_CAN_CrcErrorIsr_Callback();
        #endif /* System_CAN_CRC_ERROR_ISR_CALLBACK */
    }
#endif /* System_CAN_CRC_ERR */


#if (System_CAN_BUS_OFF)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_BusOffIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Bus Off Interrupt. Places CAN Component
    *  to Stop mode. Only generated if Bus Off Interrupt enable in Customizer.
    *  Recommended setting to enable this interrupt.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Side Effects:
    *  Stops CAN component operation.
    *
    *******************************************************************************/
    void System_CAN_BusOffIsr(void) 
    {
        /* Clear Bus Off flag */
        System_CAN_INT_SR_REG.byte[1u] = System_CAN_BUS_OFF_MASK;
        (void) System_CAN_GlobalIntDisable();

        /* `#START BUS_OFF_ISR` */

        /* `#END` */

        #ifdef System_CAN_BUS_OFF_ISR_CALLBACK
            System_CAN_BusOffIsr_Callback();
        #endif /* System_CAN_BUS_OFF_ISR_CALLBACK */

        (void) System_CAN_Stop();
    }
#endif /* System_CAN_BUS_OFF */


#if (System_CAN_RX_MSG_LOST)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_MsgLostIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Message Lost Interrupt. Clears Message Lost
    *  interrupt flag. Only generated if Message Lost Interrupt enable in Customizer
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_MsgLostIsr(void) 
    {
        /* Clear Receive Message Lost flag */
        System_CAN_INT_SR_REG.byte[1u] = System_CAN_RX_MSG_LOST_MASK;

        /* `#START MESSAGE_LOST_ISR` */

        /* `#END` */

        #ifdef System_CAN_MSG_LOST_ISR_CALLBACK
            System_CAN_MsgLostIsr_Callback();
        #endif /* System_CAN_MSG_LOST_ISR_CALLBACK */
    }
#endif /* System_CAN_RX_MSG_LOST */


#if (System_CAN_TX_MESSAGE)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_MsgTXIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Transmit Message Interrupt. Clears Transmit
    *  Message interrupt flag. Only generated if Transmit Message Interrupt enable
    *  in Customizer.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Reentrant:
    *  Depends on Customer code.
    *
    *******************************************************************************/
    void System_CAN_MsgTXIsr(void) 
    {
        /* Clear Transmit Message flag */
        System_CAN_INT_SR_REG.byte[1u] = System_CAN_TX_MESSAGE_MASK;

        /* `#START MESSAGE_TRANSMITTED_ISR` */

        /* `#END` */

        #ifdef System_CAN_MSG_TX_ISR_CALLBACK
            System_CAN_MsgTXIsr_Callback();
        #endif /* System_CAN_MSG_TX_ISR_CALLBACK */
    }
#endif /* System_CAN_TX_MESSAGE */


#if (System_CAN_RX_MESSAGE)
    /*******************************************************************************
    * FUNCTION NAME:   System_CAN_MsgRXIsr
    ********************************************************************************
    *
    * Summary:
    *  This function is entry point to Receive Message Interrupt. Clears Receive
    *  Message interrupt flag and call appropriate handlers for Basic and Full
    *  interrupt based mailboxes. Only generated if Receive Message Interrupt
    *  enable in Customizer. Recommended setting to enable this interrupt.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void System_CAN_MsgRXIsr(void) 
    {
        uint8 mailboxNumber;
        uint16 shift = 0x01u;

        /* Clear Receive Message flag */
        System_CAN_INT_SR_REG.byte[1u] = System_CAN_RX_MESSAGE_MASK;

        /* `#START MESSAGE_RECEIVE_ISR` */

        /* `#END` */

        #ifdef System_CAN_MSG_RX_ISR_CALLBACK
            System_CAN_MsgRXIsr_Callback();
        #endif /* System_CAN_MSG_RX_ISR_CALLBACK */

        for (mailboxNumber = 0u; mailboxNumber < System_CAN_NUMBER_OF_RX_MAILBOXES; mailboxNumber++)
        {
            if ((CY_GET_REG16((reg16 *) &System_CAN_BUF_SR_REG.byte[0u]) & shift) != 0u)
            {
                if ((System_CAN_RX[mailboxNumber].rxcmd.byte[0u] & System_CAN_RX_INT_ENABLE_MASK) != 0u)
                {
                    if ((System_CAN_RX_MAILBOX_TYPE & shift) != 0u)
                    {
                        /* RX Full mailboxes handler */
                    }
                    else
                    {
                        /* RX Basic mailbox handler */
                        System_CAN_ReceiveMsg(mailboxNumber);
                    }
                }
            }
            shift <<= 1u;
        }
    }
#endif /* System_CAN_RX_MESSAGE */


/*******************************************************************************
* Function Name: System_CAN_ISR
********************************************************************************
*
* Summary:
*  This ISR is executed when CAN Core generates and interrupt on one of events:
*  Arb_lost, Overload, Bit_err, Stuff_err, Ack_err, Form_err, Crc_err,
*  Buss_off, Rx_msg_lost, Tx_msg or Rx_msg. The interrupt sources depends
*  on the Customizer inputs.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
CY_ISR(System_CAN_ISR)
{
    #ifdef System_CAN_ISR_INTERRUPT_CALLBACK
        System_CAN_ISR_InterruptCallback();
    #endif /* System_CAN_ISR_INTERRUPT_CALLBACK */
    
    /* Place your Interrupt code here. */
    /* `#START CAN_ISR` */

    /* `#END` */
    
    /* Arbitration */
    #if (System_CAN_ARB_LOST && (System_CAN_ARB_LOST_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[0u] & System_CAN_ARBITRATION_LOST_MASK) != 0u)
        {
            System_CAN_ArbLostIsr();
        }
    #endif /* System_CAN_ARB_LOST && System_CAN_ARB_LOST_USE_HELPER */

    /* Overload Error */
    #if (System_CAN_OVERLOAD && (System_CAN_OVERLOAD_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[0u] & System_CAN_OVERLOAD_ERROR_MASK) != 0u)
        {
            System_CAN_OvrLdErrorIsr();
        }
    #endif /* System_CAN_OVERLOAD && System_CAN_OVERLOAD_USE_HELPER */

    /* Bit Error */
    #if (System_CAN_BIT_ERR && (System_CAN_BIT_ERR_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[0u] & System_CAN_BIT_ERROR_MASK) != 0u)
        {
            System_CAN_BitErrorIsr();
        }
    #endif /* System_CAN_BIT_ERR && System_CAN_BIT_ERR_USE_HELPER */

    /* Bit Staff Error */
    #if (System_CAN_STUFF_ERR && (System_CAN_STUFF_ERR_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[0u] & System_CAN_STUFF_ERROR_MASK) != 0u)
        {
            System_CAN_BitStuffErrorIsr();
        }
    #endif /* System_CAN_STUFF_ERR && System_CAN_STUFF_ERR_USE_HELPER */

    /* ACK Error */
    #if (System_CAN_ACK_ERR && (System_CAN_ACK_ERR_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[0u] & System_CAN_ACK_ERROR_MASK) != 0u)
        {
            System_CAN_AckErrorIsr();
        }
    #endif /* System_CAN_ACK_ERR && System_CAN_ACK_ERR_USE_HELPER */

    /* Form(msg) Error */
    #if (System_CAN_FORM_ERR && (System_CAN_FORM_ERR_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[0u] & System_CAN_FORM_ERROR_MASK) != 0u)
        {
            System_CAN_MsgErrorIsr();
        }
    #endif /* System_CAN_FORM_ERR && System_CAN_FORM_ERR_USE_HELPER */

    /* CRC Error */
    #if (System_CAN_CRC_ERR && (System_CAN_CRC_ERR_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[1u] & System_CAN_CRC_ERROR_MASK) != 0u)
        {
            System_CAN_CrcErrorIsr();
        }
    #endif /* System_CAN_CRC_ERR && System_CAN_CRC_ERR_USE_HELPER */

    /* Bus Off state */
    #if (System_CAN_BUS_OFF && (System_CAN_BUS_OFF_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[1u] & System_CAN_BUS_OFF_MASK) != 0u)
        {
            System_CAN_BusOffIsr();
        }
    #endif /* System_CAN_BUS_OFF && System_CAN_BUS_OFF_USE_HELPER */

    /* Message Lost */
    #if (System_CAN_RX_MSG_LOST && (System_CAN_RX_MSG_LOST_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[1u] & System_CAN_RX_MSG_LOST_MASK) != 0u)
        {
            System_CAN_MsgLostIsr();
        }
    #endif /* System_CAN_RX_MSG_LOST && System_CAN_RX_MSG_LOST_USE_HELPER */

    /* TX Message Send */
    #if (System_CAN_TX_MESSAGE && (System_CAN_TX_MESSAGE_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[1u] & System_CAN_TX_MESSAGE_MASK) != 0u)
        {
            System_CAN_MsgTXIsr();
        }
    #endif /* System_CAN_TX_MESSAGE && System_CAN_TX_MESSAGE_USE_HELPER */

    /* RX Message Available */
    #if (System_CAN_RX_MESSAGE && (System_CAN_RX_MESSAGE_USE_HELPER || \
        (!System_CAN_ADVANCED_INTERRUPT_CFG)))
        if ((System_CAN_INT_SR_REG.byte[1u] & System_CAN_RX_MESSAGE_MASK) != 0u)
        {
            System_CAN_MsgRXIsr();
        }
    #endif /* System_CAN_RX_MESSAGE && System_CAN_RX_MESSAGE_USE_HELPER */
}


/* [] END OF FILE */
