/***************************************************************************//**
* \file System_USBFS_audio.h
* \version 3.20
*
* \brief
*  This file provides function prototypes and constants for the USBFS component 
*  Audio class.
*
* Related Document:
*  Universal Serial Bus Device Class Definition for Audio Devices Release 1.0
*
********************************************************************************
* \copyright
* Copyright 2008-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_USBFS_System_USBFS_audio_H)
#define CY_USBFS_System_USBFS_audio_H

#include "System_USBFS.h"


/***************************************
* Custom Declarations
***************************************/

/* `#START CUSTOM_CONSTANTS` Place your declaration here */

/* `#END` */


/***************************************
*  Constants for System_USBFS_audio API.
***************************************/

/* Audio Class-Specific Request Codes (AUDIO Table A-9) */
#define System_USBFS_REQUEST_CODE_UNDEFINED     (0x00u)
#define System_USBFS_SET_CUR                    (0x01u)
#define System_USBFS_GET_CUR                    (0x81u)
#define System_USBFS_SET_MIN                    (0x02u)
#define System_USBFS_GET_MIN                    (0x82u)
#define System_USBFS_SET_MAX                    (0x03u)
#define System_USBFS_GET_MAX                    (0x83u)
#define System_USBFS_SET_RES                    (0x04u)
#define System_USBFS_GET_RES                    (0x84u)
#define System_USBFS_SET_MEM                    (0x05u)
#define System_USBFS_GET_MEM                    (0x85u)
#define System_USBFS_GET_STAT                   (0xFFu)

/* point Control Selectors (AUDIO Table A-19) */
#define System_USBFS_EP_CONTROL_UNDEFINED       (0x00u)
#define System_USBFS_SAMPLING_FREQ_CONTROL      (0x01u)
#define System_USBFS_PITCH_CONTROL              (0x02u)

/* Feature Unit Control Selectors (AUDIO Table A-11) */
#define System_USBFS_FU_CONTROL_UNDEFINED       (0x00u)
#define System_USBFS_MUTE_CONTROL               (0x01u)
#define System_USBFS_VOLUME_CONTROL             (0x02u)
#define System_USBFS_BASS_CONTROL               (0x03u)
#define System_USBFS_MID_CONTROL                (0x04u)
#define System_USBFS_TREBLE_CONTROL             (0x05u)
#define System_USBFS_GRAPHIC_EQUALIZER_CONTROL  (0x06u)
#define System_USBFS_AUTOMATIC_GAIN_CONTROL     (0x07u)
#define System_USBFS_DELAY_CONTROL              (0x08u)
#define System_USBFS_BASS_BOOST_CONTROL         (0x09u)
#define System_USBFS_LOUDNESS_CONTROL           (0x0Au)

#define System_USBFS_SAMPLE_FREQ_LEN            (3u)
#define System_USBFS_VOLUME_LEN                 (2u)

#if !defined(USER_SUPPLIED_DEFAULT_VOLUME_VALUE)
    #define System_USBFS_VOL_MIN_MSB            (0x80u)
    #define System_USBFS_VOL_MIN_LSB            (0x01u)
    #define System_USBFS_VOL_MAX_MSB            (0x7Fu)
    #define System_USBFS_VOL_MAX_LSB            (0xFFu)
    #define System_USBFS_VOL_RES_MSB            (0x00u)
    #define System_USBFS_VOL_RES_LSB            (0x01u)
#endif /* USER_SUPPLIED_DEFAULT_VOLUME_VALUE */


/***************************************
* External data references
***************************************/
/**
* \addtogroup group_audio
* @{
*/
extern volatile uint8 System_USBFS_currentSampleFrequency[System_USBFS_MAX_EP][System_USBFS_SAMPLE_FREQ_LEN];
extern volatile uint8 System_USBFS_frequencyChanged;
extern volatile uint8 System_USBFS_currentMute;
extern volatile uint8 System_USBFS_currentVolume[System_USBFS_VOLUME_LEN];
/** @} audio */

extern volatile uint8 System_USBFS_minimumVolume[System_USBFS_VOLUME_LEN];
extern volatile uint8 System_USBFS_maximumVolume[System_USBFS_VOLUME_LEN];
extern volatile uint8 System_USBFS_resolutionVolume[System_USBFS_VOLUME_LEN];

#endif /*  CY_USBFS_System_USBFS_audio_H */


/* [] END OF FILE */
