/***************************************************************************//**
* \file System_USBFS_cdc.h
* \version 3.20
*
* \brief
*  This file provides function prototypes and constants for the USBFS component 
*  CDC class.
*
* Related Document:
*  Universal Serial Bus Class Definitions for Communication Devices Version 1.1
*
********************************************************************************
* \copyright
* Copyright 2012-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_USBFS_System_USBFS_cdc_H)
#define CY_USBFS_System_USBFS_cdc_H

#include "System_USBFS.h"


/*******************************************************************************
* Prototypes of the System_USBFS_cdc API.
*******************************************************************************/
/**
* \addtogroup group_cdc
* @{
*/
#if (System_USBFS_ENABLE_CDC_CLASS_API != 0u)
    uint8 System_USBFS_CDC_Init(void)            ;
    void System_USBFS_PutData(const uint8* pData, uint16 length) ;
    void System_USBFS_PutString(const char8 string[])            ;
    void System_USBFS_PutChar(char8 txDataByte) ;
    void System_USBFS_PutCRLF(void)             ;
    uint16 System_USBFS_GetCount(void)          ;
    uint8  System_USBFS_CDCIsReady(void)        ;
    uint8  System_USBFS_DataIsReady(void)       ;
    uint16 System_USBFS_GetData(uint8* pData, uint16 length)     ;
    uint16 System_USBFS_GetAll(uint8* pData)    ;
    uint8  System_USBFS_GetChar(void)           ;
    uint8  System_USBFS_IsLineChanged(void)     ;
    uint32 System_USBFS_GetDTERate(void)        ;
    uint8  System_USBFS_GetCharFormat(void)     ;
    uint8  System_USBFS_GetParityType(void)     ;
    uint8  System_USBFS_GetDataBits(void)       ;
    uint16 System_USBFS_GetLineControl(void)    ;
    void System_USBFS_SendSerialState (uint16 serialState) ;
    uint16 System_USBFS_GetSerialState (void)   ;
    void System_USBFS_SetComPort (uint8 comNumber) ;
    uint8 System_USBFS_GetComPort (void)        ;
    uint8 System_USBFS_NotificationIsReady(void) ;

#endif  /* (System_USBFS_ENABLE_CDC_CLASS_API) */
/** @} cdc */

/*******************************************************************************
*  Constants for System_USBFS_cdc API.
*******************************************************************************/

/* CDC Class-Specific Request Codes (CDC ver 1.2 Table 19) */
#define System_USBFS_CDC_SET_LINE_CODING        (0x20u)
#define System_USBFS_CDC_GET_LINE_CODING        (0x21u)
#define System_USBFS_CDC_SET_CONTROL_LINE_STATE (0x22u)

/*PSTN Subclass Specific Notifications (CDC ver 1.2 Table 30)*/
#define System_USBFS_SERIAL_STATE               (0x20u)

#define System_USBFS_LINE_CODING_CHANGED        (0x01u)
#define System_USBFS_LINE_CONTROL_CHANGED       (0x02u)

#define System_USBFS_1_STOPBIT                  (0x00u)
#define System_USBFS_1_5_STOPBITS               (0x01u)
#define System_USBFS_2_STOPBITS                 (0x02u)

#define System_USBFS_PARITY_NONE                (0x00u)
#define System_USBFS_PARITY_ODD                 (0x01u)
#define System_USBFS_PARITY_EVEN                (0x02u)
#define System_USBFS_PARITY_MARK                (0x03u)
#define System_USBFS_PARITY_SPACE               (0x04u)

#define System_USBFS_LINE_CODING_SIZE           (0x07u)
#define System_USBFS_LINE_CODING_RATE           (0x00u)
#define System_USBFS_LINE_CODING_STOP_BITS      (0x04u)
#define System_USBFS_LINE_CODING_PARITY         (0x05u)
#define System_USBFS_LINE_CODING_DATA_BITS      (0x06u)

#define System_USBFS_LINE_CONTROL_DTR           (0x01u)
#define System_USBFS_LINE_CONTROL_RTS           (0x02u)

#define System_USBFS_MAX_MULTI_COM_NUM          (2u) 

#define System_USBFS_COM_PORT1                  (0u) 
#define System_USBFS_COM_PORT2                  (1u) 

#define System_USBFS_SUCCESS                    (0u)
#define System_USBFS_FAILURE                    (1u)

#define System_USBFS_SERIAL_STATE_SIZE          (10u)

/* SerialState constants*/
#define System_USBFS_SERIAL_STATE_REQUEST_TYPE  (0xA1u)
#define System_USBFS_SERIAL_STATE_LENGTH        (0x2u)

/*******************************************************************************
* External data references
*******************************************************************************/
/**
* \addtogroup group_cdc
* @{
*/
extern volatile uint8  System_USBFS_linesCoding[System_USBFS_MAX_MULTI_COM_NUM][System_USBFS_LINE_CODING_SIZE];
extern volatile uint8  System_USBFS_linesChanged[System_USBFS_MAX_MULTI_COM_NUM];
extern volatile uint16 System_USBFS_linesControlBitmap[System_USBFS_MAX_MULTI_COM_NUM];
extern volatile uint16 System_USBFS_serialStateBitmap[System_USBFS_MAX_MULTI_COM_NUM];
extern volatile uint8  System_USBFS_cdcDataInEp[System_USBFS_MAX_MULTI_COM_NUM];
extern volatile uint8  System_USBFS_cdcDataOutEp[System_USBFS_MAX_MULTI_COM_NUM];
extern volatile uint8  System_USBFS_cdcCommInInterruptEp[System_USBFS_MAX_MULTI_COM_NUM];
/** @} cdc */

/*******************************************************************************
* The following code is DEPRECATED and
* must not be used.
*******************************************************************************/


#define System_USBFS_lineCoding             System_USBFS_linesCoding[0]
#define System_USBFS_lineChanged            System_USBFS_linesChanged[0]
#define System_USBFS_lineControlBitmap      System_USBFS_linesControlBitmap[0]
#define System_USBFS_cdc_data_in_ep         System_USBFS_cdcDataInEp[0]
#define System_USBFS_cdc_data_out_ep        System_USBFS_cdcDataOutEp[0]

#endif /* (CY_USBFS_System_USBFS_cdc_H) */


/* [] END OF FILE */
