/***************************************************************************//**
* \file .h
* \version 3.20
*
* \brief
*  This file provides private function prototypes and constants for the 
*  USBFS component. It is not intended to be used in the user project.
*
********************************************************************************
* \copyright
* Copyright 2013-2016, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_USBFS_System_USBFS_pvt_H)
#define CY_USBFS_System_USBFS_pvt_H

#include "System_USBFS.h"
   
#ifdef System_USBFS_ENABLE_AUDIO_CLASS
    #include "System_USBFS_audio.h"
#endif /* System_USBFS_ENABLE_AUDIO_CLASS */

#ifdef System_USBFS_ENABLE_CDC_CLASS
    #include "System_USBFS_cdc.h"
#endif /* System_USBFS_ENABLE_CDC_CLASS */

#if (System_USBFS_ENABLE_MIDI_CLASS)
    #include "System_USBFS_midi.h"
#endif /* (System_USBFS_ENABLE_MIDI_CLASS) */

#if (System_USBFS_ENABLE_MSC_CLASS)
    #include "System_USBFS_msc.h"
#endif /* (System_USBFS_ENABLE_MSC_CLASS) */

#if (System_USBFS_EP_MANAGEMENT_DMA)
    #if (CY_PSOC4)
        #include <CyDMA.h>
    #else
        #include <CyDmac.h>
        #if ((System_USBFS_EP_MANAGEMENT_DMA_AUTO) && (System_USBFS_EP_DMA_AUTO_OPT == 0u))
            #include "System_USBFS_EP_DMA_Done_isr.h"
            #include "System_USBFS_EP8_DMA_Done_SR.h"
            #include "System_USBFS_EP17_DMA_Done_SR.h"
        #endif /* ((System_USBFS_EP_MANAGEMENT_DMA_AUTO) && (System_USBFS_EP_DMA_AUTO_OPT == 0u)) */
    #endif /* (CY_PSOC4) */
#endif /* (System_USBFS_EP_MANAGEMENT_DMA) */

#if (System_USBFS_DMA1_ACTIVE)
    #include "System_USBFS_ep1_dma.h"
    #define System_USBFS_EP1_DMA_CH     (System_USBFS_ep1_dma_CHANNEL)
#endif /* (System_USBFS_DMA1_ACTIVE) */

#if (System_USBFS_DMA2_ACTIVE)
    #include "System_USBFS_ep2_dma.h"
    #define System_USBFS_EP2_DMA_CH     (System_USBFS_ep2_dma_CHANNEL)
#endif /* (System_USBFS_DMA2_ACTIVE) */

#if (System_USBFS_DMA3_ACTIVE)
    #include "System_USBFS_ep3_dma.h"
    #define System_USBFS_EP3_DMA_CH     (System_USBFS_ep3_dma_CHANNEL)
#endif /* (System_USBFS_DMA3_ACTIVE) */

#if (System_USBFS_DMA4_ACTIVE)
    #include "System_USBFS_ep4_dma.h"
    #define System_USBFS_EP4_DMA_CH     (System_USBFS_ep4_dma_CHANNEL)
#endif /* (System_USBFS_DMA4_ACTIVE) */

#if (System_USBFS_DMA5_ACTIVE)
    #include "System_USBFS_ep5_dma.h"
    #define System_USBFS_EP5_DMA_CH     (System_USBFS_ep5_dma_CHANNEL)
#endif /* (System_USBFS_DMA5_ACTIVE) */

#if (System_USBFS_DMA6_ACTIVE)
    #include "System_USBFS_ep6_dma.h"
    #define System_USBFS_EP6_DMA_CH     (System_USBFS_ep6_dma_CHANNEL)
#endif /* (System_USBFS_DMA6_ACTIVE) */

#if (System_USBFS_DMA7_ACTIVE)
    #include "System_USBFS_ep7_dma.h"
    #define System_USBFS_EP7_DMA_CH     (System_USBFS_ep7_dma_CHANNEL)
#endif /* (System_USBFS_DMA7_ACTIVE) */

#if (System_USBFS_DMA8_ACTIVE)
    #include "System_USBFS_ep8_dma.h"
    #define System_USBFS_EP8_DMA_CH     (System_USBFS_ep8_dma_CHANNEL)
#endif /* (System_USBFS_DMA8_ACTIVE) */


/***************************************
*     Private Variables
***************************************/

/* Generated external references for descriptors. */
extern const uint8 CYCODE System_USBFS_DEVICE0_DESCR[18u];
extern const uint8 CYCODE System_USBFS_DEVICE0_CONFIGURATION0_DESCR[25u];
extern const T_System_USBFS_EP_SETTINGS_BLOCK CYCODE System_USBFS_DEVICE0_CONFIGURATION0_EP_SETTINGS_TABLE[1u];
extern const uint8 CYCODE System_USBFS_DEVICE0_CONFIGURATION0_INTERFACE_CLASS[1u];
extern const T_System_USBFS_LUT CYCODE System_USBFS_DEVICE0_CONFIGURATION0_TABLE[4u];
extern const T_System_USBFS_LUT CYCODE System_USBFS_DEVICE0_TABLE[3u];
extern const T_System_USBFS_LUT CYCODE System_USBFS_TABLE[1u];
extern const uint8 CYCODE System_USBFS_STRING_DESCRIPTORS[99u];


extern const uint8 CYCODE System_USBFS_MSOS_DESCRIPTOR[System_USBFS_MSOS_DESCRIPTOR_LENGTH];
extern const uint8 CYCODE System_USBFS_MSOS_CONFIGURATION_DESCR[System_USBFS_MSOS_CONF_DESCR_LENGTH];
#if defined(System_USBFS_ENABLE_IDSN_STRING)
    extern uint8 System_USBFS_idSerialNumberStringDescriptor[System_USBFS_IDSN_DESCR_LENGTH];
#endif /* (System_USBFS_ENABLE_IDSN_STRING) */

extern volatile uint8 System_USBFS_interfaceNumber;
extern volatile uint8 System_USBFS_interfaceSetting[System_USBFS_MAX_INTERFACES_NUMBER];
extern volatile uint8 System_USBFS_interfaceSettingLast[System_USBFS_MAX_INTERFACES_NUMBER];
extern volatile uint8 System_USBFS_deviceAddress;
extern volatile uint8 System_USBFS_interfaceStatus[System_USBFS_MAX_INTERFACES_NUMBER];
extern const uint8 CYCODE *System_USBFS_interfaceClass;

extern volatile T_System_USBFS_EP_CTL_BLOCK System_USBFS_EP[System_USBFS_MAX_EP];
extern volatile T_System_USBFS_TD System_USBFS_currentTD;

#if (System_USBFS_EP_MANAGEMENT_DMA)
    #if (CY_PSOC4)
        extern const uint8 System_USBFS_DmaChan[System_USBFS_MAX_EP];
    #else
        extern uint8 System_USBFS_DmaChan[System_USBFS_MAX_EP];
        extern uint8 System_USBFS_DmaTd  [System_USBFS_MAX_EP];
    #endif /* (CY_PSOC4) */
#endif /* (System_USBFS_EP_MANAGEMENT_DMA) */

#if (System_USBFS_EP_MANAGEMENT_DMA_AUTO)
#if (CY_PSOC4)
    extern uint8  System_USBFS_DmaEpBurstCnt   [System_USBFS_MAX_EP];
    extern uint8  System_USBFS_DmaEpLastBurstEl[System_USBFS_MAX_EP];

    extern uint8  System_USBFS_DmaEpBurstCntBackup  [System_USBFS_MAX_EP];
    extern uint32 System_USBFS_DmaEpBufferAddrBackup[System_USBFS_MAX_EP];
    
    extern const uint8 System_USBFS_DmaReqOut     [System_USBFS_MAX_EP];    
    extern const uint8 System_USBFS_DmaBurstEndOut[System_USBFS_MAX_EP];
#else
    #if (System_USBFS_EP_DMA_AUTO_OPT == 0u)
        extern uint8 System_USBFS_DmaNextTd[System_USBFS_MAX_EP];
        extern volatile uint16 System_USBFS_inLength [System_USBFS_MAX_EP];
        extern volatile uint8  System_USBFS_inBufFull[System_USBFS_MAX_EP];
        extern const uint8 System_USBFS_epX_TD_TERMOUT_EN[System_USBFS_MAX_EP];
        extern const uint8 *System_USBFS_inDataPointer[System_USBFS_MAX_EP];
    #endif /* (System_USBFS_EP_DMA_AUTO_OPT == 0u) */
#endif /* CY_PSOC4 */
#endif /* (System_USBFS_EP_MANAGEMENT_DMA_AUTO) */

extern volatile uint8 System_USBFS_ep0Toggle;
extern volatile uint8 System_USBFS_lastPacketSize;
extern volatile uint8 System_USBFS_ep0Mode;
extern volatile uint8 System_USBFS_ep0Count;
extern volatile uint16 System_USBFS_transferByteCount;


/***************************************
*     Private Function Prototypes
***************************************/
void  System_USBFS_ReInitComponent(void)            ;
void  System_USBFS_HandleSetup(void)                ;
void  System_USBFS_HandleIN(void)                   ;
void  System_USBFS_HandleOUT(void)                  ;
void  System_USBFS_LoadEP0(void)                    ;
uint8 System_USBFS_InitControlRead(void)            ;
uint8 System_USBFS_InitControlWrite(void)           ;
void  System_USBFS_ControlReadDataStage(void)       ;
void  System_USBFS_ControlReadStatusStage(void)     ;
void  System_USBFS_ControlReadPrematureStatus(void) ;
uint8 System_USBFS_InitControlWrite(void)           ;
uint8 System_USBFS_InitZeroLengthControlTransfer(void) ;
void  System_USBFS_ControlWriteDataStage(void)      ;
void  System_USBFS_ControlWriteStatusStage(void)    ;
void  System_USBFS_ControlWritePrematureStatus(void);
uint8 System_USBFS_InitNoDataControlTransfer(void)  ;
void  System_USBFS_NoDataControlStatusStage(void)   ;
void  System_USBFS_InitializeStatusBlock(void)      ;
void  System_USBFS_UpdateStatusBlock(uint8 completionCode) ;
uint8 System_USBFS_DispatchClassRqst(void)          ;

void System_USBFS_Config(uint8 clearAltSetting) ;
void System_USBFS_ConfigAltChanged(void)        ;
void System_USBFS_ConfigReg(void)               ;
void System_USBFS_EpStateInit(void)             ;


const T_System_USBFS_LUT CYCODE *System_USBFS_GetConfigTablePtr(uint8 confIndex);
const T_System_USBFS_LUT CYCODE *System_USBFS_GetDeviceTablePtr(void)           ;
#if (System_USBFS_BOS_ENABLE)
    const T_System_USBFS_LUT CYCODE *System_USBFS_GetBOSPtr(void)               ;
#endif /* (System_USBFS_BOS_ENABLE) */
const uint8 CYCODE *System_USBFS_GetInterfaceClassTablePtr(void)                    ;
uint8 System_USBFS_ClearEndpointHalt(void)                                          ;
uint8 System_USBFS_SetEndpointHalt(void)                                            ;
uint8 System_USBFS_ValidateAlternateSetting(void)                                   ;

void System_USBFS_SaveConfig(void)      ;
void System_USBFS_RestoreConfig(void)   ;

#if (CY_PSOC3 || CY_PSOC5LP)
    #if (System_USBFS_EP_MANAGEMENT_DMA_AUTO && (System_USBFS_EP_DMA_AUTO_OPT == 0u))
        void System_USBFS_LoadNextInEP(uint8 epNumber, uint8 mode)  ;
    #endif /* (System_USBFS_EP_MANAGEMENT_DMA_AUTO && (System_USBFS_EP_DMA_AUTO_OPT == 0u)) */
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

#if defined(System_USBFS_ENABLE_IDSN_STRING)
    void System_USBFS_ReadDieID(uint8 descr[])  ;
#endif /* System_USBFS_ENABLE_IDSN_STRING */

#if defined(System_USBFS_ENABLE_HID_CLASS)
    uint8 System_USBFS_DispatchHIDClassRqst(void) ;
#endif /* (System_USBFS_ENABLE_HID_CLASS) */

#if defined(System_USBFS_ENABLE_AUDIO_CLASS)
    uint8 System_USBFS_DispatchAUDIOClassRqst(void) ;
#endif /* (System_USBFS_ENABLE_AUDIO_CLASS) */

#if defined(System_USBFS_ENABLE_CDC_CLASS)
    uint8 System_USBFS_DispatchCDCClassRqst(void) ;
#endif /* (System_USBFS_ENABLE_CDC_CLASS) */

#if (System_USBFS_ENABLE_MSC_CLASS)
    #if (System_USBFS_HANDLE_MSC_REQUESTS)
        uint8 System_USBFS_DispatchMSCClassRqst(void) ;
    #endif /* (System_USBFS_HANDLE_MSC_REQUESTS) */
#endif /* (System_USBFS_ENABLE_MSC_CLASS */

CY_ISR_PROTO(System_USBFS_EP_0_ISR);
CY_ISR_PROTO(System_USBFS_BUS_RESET_ISR);

#if (System_USBFS_SOF_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_SOF_ISR);
#endif /* (System_USBFS_SOF_ISR_ACTIVE) */

#if (System_USBFS_EP1_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_EP_1_ISR);
#endif /* (System_USBFS_EP1_ISR_ACTIVE) */

#if (System_USBFS_EP2_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_EP_2_ISR);
#endif /* (System_USBFS_EP2_ISR_ACTIVE) */

#if (System_USBFS_EP3_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_EP_3_ISR);
#endif /* (System_USBFS_EP3_ISR_ACTIVE) */

#if (System_USBFS_EP4_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_EP_4_ISR);
#endif /* (System_USBFS_EP4_ISR_ACTIVE) */

#if (System_USBFS_EP5_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_EP_5_ISR);
#endif /* (System_USBFS_EP5_ISR_ACTIVE) */

#if (System_USBFS_EP6_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_EP_6_ISR);
#endif /* (System_USBFS_EP6_ISR_ACTIVE) */

#if (System_USBFS_EP7_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_EP_7_ISR);
#endif /* (System_USBFS_EP7_ISR_ACTIVE) */

#if (System_USBFS_EP8_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_EP_8_ISR);
#endif /* (System_USBFS_EP8_ISR_ACTIVE) */

#if (System_USBFS_EP_MANAGEMENT_DMA)
    CY_ISR_PROTO(System_USBFS_ARB_ISR);
#endif /* (System_USBFS_EP_MANAGEMENT_DMA) */

#if (System_USBFS_DP_ISR_ACTIVE)
    CY_ISR_PROTO(System_USBFS_DP_ISR);
#endif /* (System_USBFS_DP_ISR_ACTIVE) */

#if (CY_PSOC4)
    CY_ISR_PROTO(System_USBFS_INTR_HI_ISR);
    CY_ISR_PROTO(System_USBFS_INTR_MED_ISR);
    CY_ISR_PROTO(System_USBFS_INTR_LO_ISR);
    #if (System_USBFS_LPM_ACTIVE)
        CY_ISR_PROTO(System_USBFS_LPM_ISR);
    #endif /* (System_USBFS_LPM_ACTIVE) */
#endif /* (CY_PSOC4) */

#if (System_USBFS_EP_MANAGEMENT_DMA_AUTO)
#if (CY_PSOC4)
    #if (System_USBFS_DMA1_ACTIVE)
        void System_USBFS_EP1_DMA_DONE_ISR(void);
    #endif /* (System_USBFS_DMA1_ACTIVE) */

    #if (System_USBFS_DMA2_ACTIVE)
        void System_USBFS_EP2_DMA_DONE_ISR(void);
    #endif /* (System_USBFS_DMA2_ACTIVE) */

    #if (System_USBFS_DMA3_ACTIVE)
        void System_USBFS_EP3_DMA_DONE_ISR(void);
    #endif /* (System_USBFS_DMA3_ACTIVE) */

    #if (System_USBFS_DMA4_ACTIVE)
        void System_USBFS_EP4_DMA_DONE_ISR(void);
    #endif /* (System_USBFS_DMA4_ACTIVE) */

    #if (System_USBFS_DMA5_ACTIVE)
        void System_USBFS_EP5_DMA_DONE_ISR(void);
    #endif /* (System_USBFS_DMA5_ACTIVE) */

    #if (System_USBFS_DMA6_ACTIVE)
        void System_USBFS_EP6_DMA_DONE_ISR(void);
    #endif /* (System_USBFS_DMA6_ACTIVE) */

    #if (System_USBFS_DMA7_ACTIVE)
        void System_USBFS_EP7_DMA_DONE_ISR(void);
    #endif /* (System_USBFS_DMA7_ACTIVE) */

    #if (System_USBFS_DMA8_ACTIVE)
        void System_USBFS_EP8_DMA_DONE_ISR(void);
    #endif /* (System_USBFS_DMA8_ACTIVE) */

#else
    #if (System_USBFS_EP_DMA_AUTO_OPT == 0u)
        CY_ISR_PROTO(System_USBFS_EP_DMA_DONE_ISR);
    #endif /* (System_USBFS_EP_DMA_AUTO_OPT == 0u) */
#endif /* (CY_PSOC4) */
#endif /* (System_USBFS_EP_MANAGEMENT_DMA_AUTO) */


/***************************************
*         Request Handlers
***************************************/

uint8 System_USBFS_HandleStandardRqst(void) ;
uint8 System_USBFS_DispatchClassRqst(void)  ;
uint8 System_USBFS_HandleVendorRqst(void)   ;


/***************************************
*    HID Internal references
***************************************/

#if defined(System_USBFS_ENABLE_HID_CLASS)
    void System_USBFS_FindReport(void)            ;
    void System_USBFS_FindReportDescriptor(void)  ;
    void System_USBFS_FindHidClassDecriptor(void) ;
#endif /* System_USBFS_ENABLE_HID_CLASS */


/***************************************
*    MIDI Internal references
***************************************/

#if defined(System_USBFS_ENABLE_MIDI_STREAMING)
    void System_USBFS_MIDI_IN_EP_Service(void)  ;
#endif /* (System_USBFS_ENABLE_MIDI_STREAMING) */


/***************************************
*    CDC Internal references
***************************************/

#if defined(System_USBFS_ENABLE_CDC_CLASS)

    typedef struct
    {
        uint8  bRequestType;
        uint8  bNotification;
        uint8  wValue;
        uint8  wValueMSB;
        uint8  wIndex;
        uint8  wIndexMSB;
        uint8  wLength;
        uint8  wLengthMSB;
        uint8  wSerialState;
        uint8  wSerialStateMSB;
    } t_System_USBFS_cdc_notification;

    uint8 System_USBFS_GetInterfaceComPort(uint8 interface) ;
    uint8 System_USBFS_Cdc_EpInit( const T_System_USBFS_EP_SETTINGS_BLOCK CYCODE *pEP, uint8 epNum, uint8 cdcComNums) ;

    extern volatile uint8  System_USBFS_cdc_dataInEpList[System_USBFS_MAX_MULTI_COM_NUM];
    extern volatile uint8  System_USBFS_cdc_dataOutEpList[System_USBFS_MAX_MULTI_COM_NUM];
    extern volatile uint8  System_USBFS_cdc_commInEpList[System_USBFS_MAX_MULTI_COM_NUM];
#endif /* (System_USBFS_ENABLE_CDC_CLASS) */


#endif /* CY_USBFS_System_USBFS_pvt_H */


/* [] END OF FILE */
