/***************************************************************************//**
* \file System_USBFS_vnd.c
* \version 3.20
*
* \brief
*  This file contains the  USB vendor request handler.
*
********************************************************************************
* \copyright
* Copyright 2008-2016, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "System_USBFS_pvt.h"
#include "cyapicallbacks.h"

#if(System_USBFS_EXTERN_VND == System_USBFS_FALSE)

/***************************************
* Vendor Specific Declarations
***************************************/

/* `#START VENDOR_SPECIFIC_DECLARATIONS` Place your declaration here */

/* `#END` */


/*******************************************************************************
* Function Name: System_USBFS_HandleVendorRqst
****************************************************************************//**
*
*  This routine provide users with a method to implement vendor specific
*  requests.
*
*  To implement vendor specific requests, add your code in this function to
*  decode and disposition the request.  If the request is handled, your code
*  must set the variable "requestHandled" to TRUE, indicating that the
*  request has been handled.
*
* \return
*  requestHandled.
*
* \reentrant
*  No.
*
*******************************************************************************/
uint8 System_USBFS_HandleVendorRqst(void) 
{
    uint8 requestHandled = System_USBFS_FALSE;

    /* Check request direction: D2H or H2D. */
    if (0u != (System_USBFS_bmRequestTypeReg & System_USBFS_RQST_DIR_D2H))
    {
        /* Handle direction from device to host. */
        
        switch (System_USBFS_bRequestReg)
        {
            case System_USBFS_GET_EXTENDED_CONFIG_DESCRIPTOR:
            #if defined(System_USBFS_ENABLE_MSOS_STRING)
                System_USBFS_currentTD.pData = (volatile uint8 *) &System_USBFS_MSOS_CONFIGURATION_DESCR[0u];
                System_USBFS_currentTD.count = System_USBFS_MSOS_CONFIGURATION_DESCR[0u];
                requestHandled  = System_USBFS_InitControlRead();
            #endif /* (System_USBFS_ENABLE_MSOS_STRING) */
                break;
            
            default:
                break;
        }
    }

    /* `#START VENDOR_SPECIFIC_CODE` Place your vendor specific request here */

    /* `#END` */

#ifdef System_USBFS_HANDLE_VENDOR_RQST_CALLBACK
    if (System_USBFS_FALSE == requestHandled)
    {
        requestHandled = System_USBFS_HandleVendorRqst_Callback();
    }
#endif /* (System_USBFS_HANDLE_VENDOR_RQST_CALLBACK) */

    return (requestHandled);
}


/*******************************************************************************
* Additional user functions supporting Vendor Specific Requests
********************************************************************************/

/* `#START VENDOR_SPECIFIC_FUNCTIONS` Place any additional functions here */

/* `#END` */


#endif /* System_USBFS_EXTERN_VND */


/* [] END OF FILE */
