/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include "DSP_DFB.h"
//#include "DSP_DFB_Sequencer.h"
#include "DSP_DMA_IN1_Simulator_dma.h"
#include "DSP_DMA_IN2_Simulator_dma.h"
#include "DSP_DMA_Monitoring_dma.h"
#include "DSP_DMA_SDR_dma.h"
#include "Clock_1.h"
#include "Clock_2.h"

// ------------------

#define ARRAY_LENGTH(a) (sizeof(a) / sizeof(a[0]))

// ------------------

uint8_t g_DSP_DMA_IN1_Simulator_TD[1];
uint8_t g_DSP_DMA_IN2_Simulator_TD[1];
uint8_t g_DSP_DMA_Monitoring_TD[1];
uint8_t g_DSP_DMA_SDR_TD[1];

// ------------------

volatile uint32_t g_Monitoring_Data[8] = {};
volatile uint32_t g_SDR_Data[4] = {};

// ------------------

uint16_t g_Simulated_Monitoring_ADC_Data[2] = { 0x1234, 0x5678 };
uint16_t g_Simulated_SDR_ADC_Data[1] = { 0xfff };

// ------------------


static void dsp_initialize() {

    // [DSP_DMA_IN1_Simulator]: transfers the 12-bit simulated monitoring ADC result
    // into staging register A for DFB preprocessing. Memory to peripheral transfer.
    
    DSP_DMA_IN1_Simulator_DmaInitialize(sizeof(uint16_t), 1, HI16(CYDEV_SRAM_BASE), HI16(CYDEV_PERIPH_BASE));
    
    // Allocate 1 TD, setup it to form a circular chain
    
    g_DSP_DMA_IN1_Simulator_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(g_DSP_DMA_IN1_Simulator_TD[0], sizeof(g_Simulated_Monitoring_ADC_Data), g_DSP_DMA_IN1_Simulator_TD[0], TD_INC_SRC_ADR | DSP_DMA_IN1_Simulator__TD_TERMOUT_EN);
    CyDmaTdSetAddress(g_DSP_DMA_IN1_Simulator_TD[0], LO16((uintptr_t) &g_Simulated_Monitoring_ADC_Data[0]), LO16(DSP_DFB_DFB__STAGEA));
    CyDmaChSetInitialTd(DSP_DMA_IN1_Simulator_DmaHandle, g_DSP_DMA_IN1_Simulator_TD[0]);                

    // [DSP_DMA_IN2_Simulator]: transfers the 12-bit simulated SDR ADC result
    // into staging register B for DFB preprocessing. Memory to peripheral transfer.
    
    DSP_DMA_IN2_Simulator_DmaInitialize(sizeof(uint16_t), 1, HI16(CYDEV_SRAM_BASE), HI16(CYDEV_PERIPH_BASE));
    
    // Allocate 1 TD, setup it to form a circular chain
    
    g_DSP_DMA_IN2_Simulator_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(g_DSP_DMA_IN2_Simulator_TD[0], sizeof(g_Simulated_SDR_ADC_Data), g_DSP_DMA_IN2_Simulator_TD[0], TD_INC_SRC_ADR | DSP_DMA_IN2_Simulator__TD_TERMOUT_EN);
    CyDmaTdSetAddress(g_DSP_DMA_IN2_Simulator_TD[0], LO16((uintptr_t) &g_Simulated_SDR_ADC_Data[0]), LO16(DSP_DFB_DFB__STAGEB));
    CyDmaChSetInitialTd(DSP_DMA_IN2_Simulator_DmaHandle, g_DSP_DMA_IN2_Simulator_TD[0]);                    
       
    // [DSP_DMA_Monitoring]: transfers the 24-bit DFB monitoring channel preprocessing result
    // from holding register A into memory for further processing. Peripheral to memory transfer.
    
    DSP_DMA_Monitoring_DmaInitialize(sizeof(uint32_t), 1, HI16(CYDEV_PERIPH_BASE), HI16(CYDEV_SRAM_BASE));
    
    // Allocate 1 TD, setup it to form a circular chain
    
    g_DSP_DMA_Monitoring_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(g_DSP_DMA_Monitoring_TD[0], sizeof(g_Monitoring_Data), g_DSP_DMA_Monitoring_TD[0], TD_INC_DST_ADR | DSP_DMA_Monitoring__TD_TERMOUT_EN);
    CyDmaTdSetAddress(g_DSP_DMA_Monitoring_TD[0], LO16(DSP_DFB_DFB__HOLDA), LO16((uintptr_t) &g_Monitoring_Data[0]));
    CyDmaChSetInitialTd(DSP_DMA_Monitoring_DmaHandle, g_DSP_DMA_Monitoring_TD[0]);                

    // [DSP_DMA_SDR]: transfers the 24-bit DFB SDR channel preprocessing result
    // from holding register B into memory for further processing. Peripheral to memory transfer.
    
    DSP_DMA_SDR_DmaInitialize(sizeof(uint32_t), 1, HI16(CYDEV_PERIPH_BASE), HI16(CYDEV_SRAM_BASE));
    
    // Allocate 1 TD, setup it to form a circular chain
    
    g_DSP_DMA_SDR_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(g_DSP_DMA_SDR_TD[0], sizeof(g_SDR_Data), g_DSP_DMA_SDR_TD[0], TD_INC_DST_ADR | DSP_DMA_SDR__TD_TERMOUT_EN);
    CyDmaTdSetAddress(g_DSP_DMA_SDR_TD[0], LO16(DSP_DFB_DFB__HOLDB), LO16((uintptr_t) &g_SDR_Data[0]));
    CyDmaChSetInitialTd(DSP_DMA_SDR_DmaHandle, g_DSP_DMA_SDR_TD[0]);                    

    // DFB

 //   DSP_DFB_Sequencer_Init();
    DSP_DFB_Init();

    // STAGEA: in, 12-bit data from the monitoring SAR ADC, MUST be DALIGNed
    // STAGEB: in, 12-bit data from the SDR SAR ADC, MUST BE DALIGNed
    // HOLDA:  out, 24-bit preprocessed monitoring data
    // HOLDB:  out, 24-bit preprocessed SDR data
    
    DSP_DFB_SetCoherency(DSP_DFB_STGA_KEY_MID | DSP_DFB_STGB_KEY_MID | DSP_DFB_HOLDA_KEY_HIGH | DSP_DFB_HOLDB_KEY_HIGH);
    DSP_DFB_SetDalign(DSP_DFB_STGA_DALIGN_HIGH | DSP_DFB_STGB_DALIGN_HIGH | DSP_DFB_HOLDA_DALIGN_LOW | DSP_DFB_HOLDB_DALIGN_LOW);
}



// ------------------


static void dsp_enable() {
        
//    DSP_DFB_Sequencer_Enable();
    DSP_DFB_Enable();
    CyDmaChEnable(DSP_DMA_Monitoring_DmaHandle, 1);
    CyDmaChEnable(DSP_DMA_SDR_DmaHandle, 1);
//    CyDmaChEnable(DSP_DMA_IN1_Simulator_DmaHandle, 1);
    CyDmaChEnable(DSP_DMA_IN2_Simulator_DmaHandle, 1);

    Clock_1_Enable();
    Clock_2_Enable();
}


// ------------------


int main(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */

    /* Place your initialization/startup code here (e.g. MyInst_Start()) */

    dsp_initialize();
    dsp_enable();
    
    volatile int32_t xa;
    
    for(;;)
    {
        /* Place your application code here. */
        xa = g_Monitoring_Data[0];
        xa = g_SDR_Data[0];
    }
}

/* [] END OF FILE */
